rgph: Pair Critical Points and Compute Persistent Homology of Reeb Graphs
rgph.RdInterface to the 'ReebGraphPairing' program to compute critical points of Reeb graphs following Tu, Hajij, & Rosen (2019) doi:10.1007/978-3-030-33720-9_8 via the 'rJava' package. Also store Reeb graphs in a minimal S3 class, convert between other network data structures, and post-process pairing data to obtain extended persistent homology following Carrière & Oudot (2018) doi:10.1007/s10208-017-9370-z .
Author
Maintainer: Jason Cory Brunson cornelioid@gmail.com (ORCID)
Authors:
Satyajit Mohanty mohantysatyajit57@gmail.com
Shubham Singh shubhamus16091998@example.com
Other contributors:
Paul Rosen paul.rosen@utah.edu (ORCID) (ReebGraphPairing; GPL-3 license) [copyright holder, contributor]
Junyi Tu JXTU@salisbury.edu (ORCID) (ReebGraphPairing; GPL-3 license) [copyright holder, contributor]